@@ -1,5 +1,6 @@
 from wcd_geo_db.modules.client import Client
 
+from .modules.addresses import AddressesClient
 from .modules.bank import BankClient
 from .modules.names import NamesClient
 from .conf import Settings
@@ -13,3 +14,4 @@ class GeoClient(Client):
 
     bank: BankClient = BankClient.as_property()
     names: NamesClient = NamesClient.as_property()
+    addresses: AddressesClient = AddressesClient.as_property()
