@@ -3,16 +3,16 @@ from django.utils.translation import pgettext_lazy
 
 from pxd_tree.hierarchy import Tree, tree_indexes
 from wcd_geo_db.const import DivisionLevel
+from wcd_geo_db.modules.code_seeker.models import (
+    create_codes_model, CodesDefinableMixin, codes_mixin_indexes
+)
 
 from ..query import DivisionsQuerySet
-from .mixins import (
-    CodesDefinableMixin, NamedMixin, SynonymizedMixin,
-    create_types_field, codes_indexes
-)
+from .mixins import NamedMixin, SynonymizedMixin, create_types_field
 from .geometry import WithGeometryMixin
 
 
-__all__ = 'Division',
+__all__ = 'Division', 'DivisionCode',
 
 
 class Division(Tree, NamedMixin, SynonymizedMixin, WithGeometryMixin, CodesDefinableMixin):
@@ -22,7 +22,7 @@ class Division(Tree, NamedMixin, SynonymizedMixin, WithGeometryMixin, CodesDefin
     class Meta:
         verbose_name = pgettext_lazy('wcd_geo_db', 'Division')
         verbose_name_plural = pgettext_lazy('wcd_geo_db', 'Divisions')
-        indexes = tree_indexes() + codes_indexes()
+        indexes = tree_indexes() + codes_mixin_indexes()
 
     id = models.BigAutoField(
         primary_key=True, verbose_name=pgettext_lazy('wcd_geo_db', 'ID')
@@ -32,3 +32,10 @@ class Division(Tree, NamedMixin, SynonymizedMixin, WithGeometryMixin, CodesDefin
         choices=Levels.choices, null=False, blank=False
     )
     types = create_types_field(pgettext_lazy('wcd_geo_db', 'Division types'))
+
+
+DivisionCode = create_codes_model(
+    Division,
+    verbose_name=pgettext_lazy('wcd_geo_db', 'Division code'),
+    verbose_name_plural=pgettext_lazy('wcd_geo_db', 'Division codes'),
+)
